Installation
============

.. code-block:: bash

    pip install aiocometd

Install extras
--------------

aiocometd defines several groups of optional requirements:

- ``tests`` for running unit tests
- ``docs`` for buidling the documentation
- ``examples`` for running the examples
- ``dev`` for creating a complete development enviroment

Any combination of these options can be specified during installation.

.. code-block:: bash

    pip install aiocometd[tests,docs,examples,dev]
